==> sci_mobile_components-1.0.1.tar.gz: lib/src/components/SCITicket.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_vector_icons/flutter_vector_icons.dart';

class SCITicket extends StatelessWidget {
  final VoidCallback onPressed;
  final String namaDokter;
  final String namaPoli;
  final String tanggal;
  final String jam;

  SCITicket({
    @required this.onPressed,
    this.namaDokter,
    this.namaPoli,
    this.tanggal,
    this.jam,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      height: MediaQuery.of(context).size.height * 0.2,
      width: MediaQuery.of(context).size.width * 0.95,
      child: GestureDetector(
        onTap: onPressed,
        child: Card(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Container(
                padding: EdgeInsets.all(8.0),
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Text(
                      namaDokter,
                      style: TextStyle(
                          fontSize: 16.0, fontWeight: FontWeight.bold),
                    ),
                    Text(
                      namaPoli,
                      style: TextStyle(
                        fontSize: 15.0,
                      ),
                    ),
                    Row(
                      children: <Widget>[
                        Icon(
                          Icons.calendar_today,
                          color: Color.fromRGBO(57, 151, 203, 1),
                        ),
                        SizedBox(
                          width: 10.0,
                        ),
                        Text(
                          tanggal,
                          style: TextStyle(fontSize: 14.0),
                        ),
                      ],
                    ),
                    Row(
                      children: <Widget>[
                        Icon(
                          Icons.query_builder,
                          color: Color.fromRGBO(57, 151, 203, 1),
                        ),
                        SizedBox(
                          width: 10.0,
                        ),
                        Text(
                          jam,
                          style: TextStyle(fontSize: 14.0),
                        ),
                      ],
                    ),
                  ],
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.3,
                height: double.infinity,
                decoration: BoxDecoration(
                  gradient: LinearGradient(
                    begin: Alignment.topRight,
                    end: Alignment.bottomLeft,
                    colors: [
                      Color.fromRGBO(57, 151, 203, 1),
                      Color.fromRGBO(84, 250, 240, 1),
                    ],
                  ),
                ),
                child: Icon(
                  MaterialCommunityIcons.qrcode,
                  color: Colors.white,
                  size: 60.0,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

// Icon(
//                     MaterialCommunityIcons.barcode,
//                     color: Colors.yellow,
//                     size: 80.0,
//                   ),
// Column(
//         mainAxisSize: MainAxisSize.min,
//         children: <Widget>[
//           ListTile(
//             title: Text(
//               'Dr. Robby Hendarsono Sp. KK',
//               style: TextStyle(fontSize: 16.0),
//             ),
//             subtitle: Text(
//               'Poli Kulit dan Kelamin',
//               style: TextStyle(fontSize: 15.0),
//             ),
//           ),
//           Row(
//             children: <Widget>[
//               SizedBox(
//                 width: 15.0,
//               ),
//               Icon(
//                 Icons.calendar_today,
//                 color: Color.fromRGBO(57, 151, 203, 1),
//               ),
//               SizedBox(
//                 width: 10.0,
//               ),
//               Text(
//                 '14 - 06 - 2021',
//                 style: TextStyle(fontSize: 14.0),
//               ),
//             ],
//           ),
//           SizedBox(
//             height: 10,
//           ),
//           Row(
//             children: <Widget>[
//               SizedBox(
//                 width: 15.0,
//               ),
//               Icon(
//                 Icons.query_builder,
//                 color: Color.fromRGBO(57, 151, 203, 1),
//               ),
//               SizedBox(
//                 width: 10.0,
//               ),
//               Text(
//                 '20 : 15',
//                 style: TextStyle(fontSize: 14.0),
//               ),
//             ],
//           ),
//           SizedBox(
//             height: 10,
//           ),
//         ],
//       ),

==> sci_mobile_components-2.0.2.tar.gz: lib/src/components/SCITicket.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_vector_icons/flutter_vector_icons.dart';

class SCITicket extends StatelessWidget {
  final VoidCallback onPressed;
  final String namaDokter;
  final String namaPoli;
  final String tanggal;
  final String jam;

  SCITicket({
    required this.onPressed,
    required this.namaDokter,
    required this.namaPoli,
    required this.tanggal,
    required this.jam,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      height: MediaQuery.of(context).size.height * 0.2,
      width: MediaQuery.of(context).size.width * 0.95,
      child: GestureDetector(
        onTap: onPressed,
        child: Card(
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Container(
                padding: EdgeInsets.all(8.0),
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Text(
                      namaDokter,
                      style: TextStyle(
                          fontSize: 16.0, fontWeight: FontWeight.bold),
                    ),
                    Text(
                      namaPoli,
                      style: TextStyle(
                        fontSize: 15.0,
                      ),
                    ),
                    Row(
                      children: <Widget>[
                        Icon(
                          Icons.calendar_today,
                          color: Color.fromRGBO(57, 151, 203, 1),
                        ),
                        SizedBox(
                          width: 10.0,
                        ),
                        Text(
                          tanggal,
                          style: TextStyle(fontSize: 14.0),
                        ),
                      ],
                    ),
                    Row(
                      children: <Widget>[
                        Icon(
                          Icons.query_builder,
                          color: Color.fromRGBO(57, 151, 203, 1),
                        ),
                        SizedBox(
                          width: 10.0,
                        ),
                        Text(
                          jam,
                          style: TextStyle(fontSize: 14.0),
                        ),
                      ],
                    ),
                  ],
                ),
              ),
              Container(
                width: MediaQuery.of(context).size.width * 0.3,
                height: double.infinity,
                decoration: BoxDecoration(
                  gradient: LinearGradient(
                    begin: Alignment.topRight,
                    end: Alignment.bottomLeft,
                    colors: [
                      Color.fromRGBO(57, 151, 203, 1),
                      Color.fromRGBO(84, 250, 240, 1),
                    ],
                  ),
                ),
                child: Icon(
                  MaterialCommunityIcons.qrcode,
                  color: Colors.white,
                  size: 60.0,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

// Icon(
//                     MaterialCommunityIcons.barcode,
//                     color: Colors.yellow,
//                     size: 80.0,
//                   ),
// Column(
//         mainAxisSize: MainAxisSize.min,
//         children: <Widget>[
//           ListTile(
//             title: Text(
//               'Dr. Robby Hendarsono Sp. KK',
//               style: TextStyle(fontSize: 16.0),
//             ),
//             subtitle: Text(
//               'Poli Kulit dan Kelamin',
//               style: TextStyle(fontSize: 15.0),
//             ),
//           ),
//           Row(
//             children: <Widget>[
//               SizedBox(
//                 width: 15.0,
//               ),
//               Icon(
//                 Icons.calendar_today,
//                 color: Color.fromRGBO(57, 151, 203, 1),
//               ),
//               SizedBox(
//                 width: 10.0,
//               ),
//               Text(
//                 '14 - 06 - 2021',
//                 style: TextStyle(fontSize: 14.0),
//               ),
//             ],
//           ),
//           SizedBox(
//             height: 10,
//           ),
//           Row(
//             children: <Widget>[
//               SizedBox(
//                 width: 15.0,
//               ),
//               Icon(
//                 Icons.query_builder,
//                 color: Color.fromRGBO(57, 151, 203, 1),
//               ),
//               SizedBox(
//                 width: 10.0,
//               ),
//               Text(
//                 '20 : 15',
//                 style: TextStyle(fontSize: 14.0),
//               ),
//             ],
//           ),
//           SizedBox(
//             height: 10,
//           ),
//         ],
//       ),
